@@ -1,7 +1,7 @@
 # coding=utf-8
 from qrunner.running.runner import main
-from qrunner.case import TestCase, Page, H5Page
-from qrunner.core.api.request import HttpRequest
+from qrunner.case import TestCase, Page
+from qrunner.core.api.request import HttpRequest, ResponseResult
 from qrunner.core.android.driver import AndroidDriver
 from qrunner.core.android.element import AndroidElement
 from qrunner.core.ios.driver import IosDriver
@@ -14,6 +14,6 @@ from qrunner.utils.decorate import *
 from qrunner.utils.mock import mock, mock_en
 from qrunner.utils.config import conf
 
-__version__ = "0.9.8"
+__version__ = "0.9.20"
 __description__ = "全栈自动化测试框架"
 
