@@ -31,7 +31,7 @@ def main():
             # qrun startpro
             sub_parser_project.print_help()
         sys.exit(0)
-    elif len(sys.argv) == 3:
+    else:
         if sys.argv[1] == "create":
             args = parser.parse_args()
             main_scaffold_project(args)
