@@ -7,32 +7,34 @@ from qrunner.utils.log import logger
 
 
 class AndroidDriver(object):
-    _instance = {}
+    # _instance = {}
+    #
+    # def __new__(cls, serial_no=None):
+    #     if not serial_no:
+    #         serial_no = conf.get_name('app', 'serial_no')
+    #     if serial_no not in cls._instance:
+    #         cls._instance[serial_no] = super().__new__(cls)
+    #     return cls._instance[serial_no]
 
-    def __new__(cls, serial_no=None):
-        if not serial_no:
+    def __init__(self, serial_no=None, pkg_name=None):
+        if serial_no is None:
             serial_no = conf.get_name('app', 'serial_no')
-        if serial_no not in cls._instance:
-            cls._instance[serial_no] = super().__new__(cls)
-        return cls._instance[serial_no]
-
-    def __init__(self, serial_no=None):
-        if not serial_no:
-            self.serial_no = conf.get_name('app', 'serial_no')
         self.serial_no = serial_no
-        self.pkg_name = conf.get_name('app', 'pkg_name')
+        if pkg_name is None:
+            pkg_name = conf.get_name('app', 'pkg_name')
+        self.pkg_name = pkg_name
 
         logger.info(f'启动 android driver for {self.serial_no}')
         self.d = u2.connect(self.serial_no)
         self.session = None
 
-    @classmethod
-    def get_instance(cls, serial_no=None):
-        """Create singleton"""
-        if serial_no not in cls._instance:
-            logger.info(f'[{serial_no}] Create android driver singleton')
-            return AndroidDriver(serial_no)
-        return AndroidDriver._instance[serial_no]
+    # @classmethod
+    # def get_instance(cls, serial_no=None):
+    #     """Create singleton"""
+    #     if serial_no not in cls._instance:
+    #         logger.info(f'[{serial_no}] Create android driver singleton')
+    #         return AndroidDriver(serial_no)
+    #     return AndroidDriver._instance[serial_no]
 
     # @classmethod
     # def get_remote_instance(cls, server_url, token):
@@ -46,10 +48,13 @@ class AndroidDriver(object):
         logger.info(f'卸载应用: {pkg_name}')
         self.d.app_uninstall(pkg_name)
 
-    def install_app(self, apk_path, is_new=False):
-        if is_new:
-            self.uninstall_app(self.pkg_name)
-        logger.info(f'安装应用: {apk_path}')
+    def install_app(self, apk_path):
+        logger.info(f'覆盖安装应用: {apk_path}')
+        self.d.app_install(apk_path)
+
+    def new_install_app(self, apk_path):
+        logger.info(f'先卸载再安装应用: {apk_path}')
+        self.uninstall_app(self.pkg_name)
         self.d.app_install(apk_path)
 
     def start_app(self, pkg_name=None):
@@ -58,6 +63,12 @@ class AndroidDriver(object):
         logger.info(f'启动应用: {pkg_name}')
         self.d.app_start(pkg_name)
 
+    def force_start_app(self, pkg_name=None):
+        if not pkg_name:
+            pkg_name = self.pkg_name
+        logger.info(f'强制启动应用: {pkg_name}')
+        self.d.app_start(pkg_name, stop=True)
+
     def stop_app(self, pkg_name=None):
         if not pkg_name:
             pkg_name = self.pkg_name
@@ -72,12 +83,6 @@ class AndroidDriver(object):
         logger.info(f'退出多个应用: {app_list}')
         self.d.app_stop_all(excludes=app_list)
 
-    def force_start_app(self, pkg_name=None):
-        if not pkg_name:
-            pkg_name = self.pkg_name
-        logger.info(f'强制启动应用: {pkg_name}')
-        self.d.app_start(pkg_name, stop=True)
-
     def clear_app(self, pkg_name=None):
         if not pkg_name:
             pkg_name = self.pkg_name
@@ -232,7 +237,7 @@ class AndroidDriver(object):
             os.mkdir(img_dir)
         time_str = time.strftime('%Y%m%d%H%M%S')
         file_path = os.path.join(img_dir,
-                                 f'{file_name}-{time_str}.png')
+                                 f'{time_str}-{file_name}.png')
         logger.info(f'截图保存至: {file_path}')
         self.d.screenshot(file_path)
         # 截图并上传到allure报告
@@ -398,7 +403,7 @@ class AndroidDriver(object):
         logger.info(f'从坐标{sx},{sy} 拖动到坐标{ex},{ey}')
         self.d.drag(sx, sy, ex, ey)
 
-    def send_keys(self, text, clear=True):
+    def set_password(self, text, clear=True):
         logger.info(f'输入: {text}')
         self.d.set_fastinput_ime(True)
         if clear:
