@@ -11,27 +11,23 @@ from qrunner.core.android.driver import AndroidDriver
 from qrunner.utils.exceptions import NoSuchElementException
 
 
-class AndroidConfig:
-    alerts = ['允许', '始终允许', '仅使用期间允许', '仅在使用中允许']
-
-
 class AndroidElement(object):
     """
     安卓元素定义
     """
-    def __init__(self, *args, **kwargs):
+    def __init__(self, driver=None, *args, **kwargs):
         # 从kwargs中删掉并返回index
         self._index = kwargs.pop('index', 0)
         # 参数初始化
-        self._pkg_name = conf.get_name('app', 'pkg_name')
+        self._xpath = kwargs.get('xpath', '')
+        self._kwargs = kwargs
+        self._element: Union[UiObject, XPathSelector]
+        self._driver: AndroidDriver = driver
+        self._serial_no = self._driver.serial_no
+        self._pkg_name = self._driver.pkg_name
         self._resourceId = kwargs.pop('resourceId', '')
         if self._resourceId:
             kwargs['resourceId'] = f'{self._pkg_name}:{self._resourceId}'
-        self._xpath = kwargs.get('xpath', '')
-        self._kwargs = kwargs
-        self._element: Union[UiObject, XPathSelector] = None
-        self._serial_no = conf.get_name('app', 'serial_no')
-        self._driver = AndroidDriver.get_instance(self._serial_no)
         self._d = self._driver.d
 
     def handle_alert(self):
@@ -40,27 +36,27 @@ class AndroidElement(object):
         @return:
         """
         def click_alert(loc):
-            timeout = 2
-            try:
-                if 'id/' in loc:
-                    element = self._d(resourceId=f'{self._pkg_name}:{loc}')
-                elif '//' in loc:
-                    element = self._d.xpath(loc)
-                else:
-                    element = self._d(text=loc)
-                element.click(timeout=timeout)
-            except Exception:
-                pass
-
-        # # 弹窗列表设置
-        # alert_list = []
-        # alert_list.extend(AndroidConfig.alerts)  # 添加上面定义的默认支持弹窗列表
-        # user_set_list = conf.get_name('app', 'alerts').split(',')
-        # alert_list.extend(user_set_list)  # 添加用例在running/conf.ini中设置的弹窗列表
+            if 'id/' in loc:
+                element = self._d(resourceId=f'{self._pkg_name}:{loc}')
+            elif '//' in loc:
+                element = self._d.xpath(loc)
+            else:
+                element = self._d(text=loc)
+            element.click_exists(timeout=1)
 
         # 多线程执行点击过程
+        alert_str = conf.get_name('app', 'android_alert')
+        logger.debug(f'处理异常弹窗: {alert_str}')
+        try:
+            alert_list = alert_str.split(',')
+        except:
+            alert_list = []
         pool = ThreadPool(10)
-        pool.map(click_alert, AndroidConfig.alerts)
+        if alert_list:
+            pool.map(click_alert, alert_list)
+        else:
+            logger.debug("弹窗设置列表为空")
+        logger.debug('处理异常弹窗完成')
 
     def _find_element(self, retry=3, timeout=3):
         """
@@ -72,6 +68,7 @@ class AndroidElement(object):
         logger.info(f'查找元素: {self._kwargs},{self._index}')
         self._element = self._d.xpath(self._xpath) if \
             self._xpath else self._d(**self._kwargs)[self._index]
+        self.handle_alert()  # 处理异常弹窗
         while not self._element.wait(timeout=timeout):
             if retry > 0:
                 retry -= 1
@@ -96,7 +93,7 @@ class AndroidElement(object):
             self._driver.screenshot(f'{self._kwargs}-定位失败')
             raise NoSuchElementException(f'{self._kwargs}-定位失败')
         else:
-            self._driver.screenshot(f'{self._kwargs}')
+            self._driver.screenshot(f'{self._kwargs}-定位成功')
         return element
 
     @property
