@@ -1,6 +1,8 @@
 # @Time    : 2022/2/22 9:35
 # @Author  : kang.yang@qizhidao.com
 # @File    : request.py
+import sys
+from urllib import parse
 import requests
 import json as json_util
 from qrunner.utils.config import conf
@@ -19,14 +21,13 @@ def request(func):
         except IndexError:
             url = kwargs.get("url", "")
 
-        ResponseResult.method = func_name.upper()
-        ResponseResult.path = url
-        try:
-            base_url = eval(conf.get_name('common', 'base_url'))
-        except:
-            base_url = None
-        if (base_url is not None) and ("http" not in url):
-            url = base_url + list(args)[1]
+        if "http" not in url:
+            base_url = conf.get_name('common', 'base_url')
+            if 'http' in base_url:
+                url = parse.urljoin(base_url, url)
+            else:
+                logger.debug('请设置正确的base_url')
+                sys.exit()
 
         img_file = False
         file_type = url.split(".")[-1]
@@ -37,11 +38,11 @@ def request(func):
         auth = kwargs.get("auth", "")
 
         # 处理请求头
-        headers: dict = json_util.loads(conf.get_name('api', 'headers'))  # 从配置文件拿到登录用户请求头
+        headers: dict = json_util.loads(conf.get_name('common', 'headers'))  # 从配置文件拿到登录用户请求头
         # 如果login=False，从请求头中删掉登录态相关的键值对
         login_status = kwargs.get('login', True)
         if not login_status:
-            login_key = (conf.get_name('api', 'login_key')).split(',')
+            login_key = json_util.loads(conf.get_name('api', 'login_key'))
             for key in login_key:
                 headers.pop(key)
         # 把上层请求方法的headers参数更新到headers里面
@@ -49,7 +50,10 @@ def request(func):
         kwargs['headers'] = headers
 
         # 设置请求超时时间为5s
-        timeout_default = int(conf.get_name('api', 'timeout'))
+        try:
+            timeout_default = int(conf.get_name('common', 'timeout'))
+        except:
+            timeout_default = 10
         timeout_set = kwargs.pop("timeout", None)
         if timeout_set is not None:
             kwargs['timeout'] = timeout_set
@@ -100,40 +104,55 @@ def request(func):
 class ResponseResult:
     status_code = 200
     response = None
-    path = None
-    method = None
 
 
 class HttpRequest(object):
 
     @request
     def get(self, url, params=None, login=True, **kwargs):
-        base_url = conf.get_name('common', 'base_url')
-        if (base_url is not None) and ("http" not in url):
-            url = base_url + url
+        if "http" not in url:
+            base_url = eval(conf.get_name('common', 'base_url'))
+            if 'http' in base_url:
+                url = parse.urljoin(base_url, url)
+            else:
+                logger.debug('请设置正确的base_url')
+                sys.exit()
         return requests.get(url, params=params, **kwargs)
 
     @request
     def post(self, url, data=None, json=None, login=True, **kwargs):
-        base_url = conf.get_name('common', 'base_url')
-        if (base_url is not None) and ("http" not in url):
-            url = base_url + url
+        if "http" not in url:
+            base_url = conf.get_name('common', 'base_url')
+            logger.debug(base_url)
+            if 'http' in base_url:
+                url = parse.urljoin(base_url, url)
+            else:
+                logger.debug('请设置正确的base_url')
+                sys.exit()
         return requests.post(url, data=data, json=json, **kwargs)
 
     @request
     def put(self, url, data=None, json=None, login=True, **kwargs):
-        base_url = conf.get_name('common', 'base_url')
-        if (base_url is not None) and ("http" not in url):
-            url = base_url + url
+        if "http" not in url:
+            base_url = conf.get_name('common', 'base_url')
+            if 'http' in base_url:
+                url = parse.urljoin(base_url, url)
+            else:
+                logger.debug('请设置正确的base_url')
+                sys.exit()
         if json is not None:
             data = json_util.dumps(json)
         return requests.put(url, data=data, **kwargs)
 
     @request
     def delete(self, url, login=True, **kwargs):
-        base_url = conf.get_name('common', 'base_url')
-        if (base_url is not None) and ("http" not in url):
-            url = base_url + url
+        if "http" not in url:
+            base_url = conf.get_name('common', 'base_url')
+            if 'http' in base_url:
+                url = parse.urljoin(base_url, url)
+            else:
+                logger.debug('请设置正确的base_url')
+                sys.exit()
         return requests.delete(url, **kwargs)
 
     @property
