@@ -1,7 +1,8 @@
+import json
 import os
+import sys
 import time
 import allure
-import requests
 from selenium import webdriver
 from selenium.webdriver import DesiredCapabilities
 from selenium.webdriver import ChromeOptions
@@ -13,22 +14,23 @@ from webdriver_manager.microsoft import EdgeChromiumDriverManager
 from webdriver_manager.opera import OperaDriverManager
 from qrunner.utils.log import logger
 from qrunner.utils.config import conf
+from urllib import parse
 
 
-def relaunch(func):
-    """
-    重启chromedriver的装饰器
-    :param func: 待包裹的函数
-    :return:
-    """
-    def wrapper(self, *args, **kwargs):
-        try:
-            return func(self, *args, **kwargs)
-        except requests.exceptions.ConnectionError as _:
-            logger.warning("web driver error, relaunch now.")
-            name = conf.get_name('web', 'browser_name')
-            self.d = BrowserDriver(name)
-    return wrapper
+# def relaunch(func):
+#     """
+#     重启chromedriver的装饰器
+#     :param func: 待包裹的函数
+#     :return:
+#     """
+#     def wrapper(self, *args, **kwargs):
+#         try:
+#             return func(self, *args, **kwargs)
+#         except requests.exceptions.ConnectionError as _:
+#             logger.warning("web driver error, relaunch now.")
+#             name = conf.get_name('web', 'browser_name')
+#             self.d = BrowserDriver(name)
+#     return wrapper
 
 
 class ChromeConfig:
@@ -186,26 +188,38 @@ class Browser(object):
 class BrowserDriver(object):
     def __init__(self, browser_name=None):
         self.d = Browser(browser_name)
-        timeout = conf.get('common', 'timeout')
-        self.d.set_page_load_timeout(timeout)
-
-    @relaunch
-    def open_url(self, url):
         try:
-            base_url = eval(conf.get_name('common', 'base_url'))
+            timeout = int(conf.get_name('common', 'timeout'))
         except:
-            base_url = None
-        if (base_url is not None) and ("http" not in url):
-            url = base_url + url
+            pass
+        else:
+            self.d.set_page_load_timeout(timeout)
+
+    def open_url(self, url, login=True):
+        if "http" not in url:
+            base_url = conf.get_name('common', 'base_url')
+            if 'http' in base_url:
+                url = parse.urljoin(base_url, url)
+            else:
+                logger.debug('请设置正确的base_url')
+                sys.exit()
         logger.info(f'访问: {url}')
         self.d.get(url)
+        # 把默认请求头添加到cookie中
+        if login:
+            headers = json.loads(conf.get('common', 'headers'))
+            logger.debug(headers)
+            cookies = []
+            if headers:
+                for k, v in headers.items():
+                    cookies.append({"name": k, "value": v})
+                self.add_cookies(cookies)
+                self.refresh()
 
-    @relaunch
     def back(self):
         logger.info('返回上一页')
         self.d.back()
 
-    @relaunch
     def screenshot(self, file_name):
         """
         截图并保存到预定路径并上传到allure报告
@@ -221,7 +235,7 @@ class BrowserDriver(object):
             os.mkdir(img_dir)
         time_str = time.strftime('%Y%m%d%H%M%S')
         file_path = os.path.join(img_dir,
-                                 f'{file_name}-{time_str}.png')
+                                 f'{time_str}-{file_name}.png')
         logger.info(f'截图保存至: {file_path}')
         self.d.save_screenshot(file_path)
         # 截图并上传到allure报告
@@ -230,29 +244,17 @@ class BrowserDriver(object):
                            attachment_type=allure.attachment_type.PNG,
                            name=f'{file_name}-{time_str}')
 
-    # @relaunch
-    # def upload_pic(self, filename):
-    #     # allure.attach.file(self.d.get_screenshot_as_png(),
-    #     #                    attachment_type=allure.attachment_type.PNG,
-    #     #                    name=f'{filename}')
-    #     self.d.save_screenshot('tmp.png')
-    #     allure.attach.file('tmp.png', attachment_type=allure.attachment_type.PNG,
-    #                        name=f'{filename}-{get_time()}')
-    #     os.remove('tmp.png')
-
     @property
     def page_content(self):
         page_source = self.d.page_source
         logger.info(f'获取页面内容: \n{page_source}')
         return page_source
 
-    @relaunch
     def max_window(self):
         logger.info('窗口设置全屏')
         self.d.maximize_window()
 
-    @relaunch
-    def set_window_size(self, width, height):
+    def set_window(self, width, height):
         logger.info('设置窗口长宽')
         self.d.set_window_size(width, height)
 
@@ -260,50 +262,41 @@ class BrowserDriver(object):
         logger.info(f'获取当前打开的窗口列表')
         return self.d.window_handles
 
-    @relaunch
     def switch_window(self, old_windows):
         logger.info('切换到最新的window')
         current_windows = self.d.window_handles
         newest_window = [window for window in current_windows if window not in old_windows][0]
         self.d.switch_to.window(newest_window)
 
-    @relaunch
     def window_scroll(self, width, height):
         logger.info(f'设置scroll bar的宽高')
         js = "window.scrollTo({w},{h});".format(w=str(width), h=str(height))
         self.d.execute_script(js)
 
-    @relaunch
     def switch_to_frame(self, frame_id):
         logger.info(f'切换到frame {frame_id}')
         self.d.switch_to.frame(frame_id)
 
-    @relaunch
     def switch_to_frame_out(self):
         logger.info('从frame中切出来')
         self.d.switch_to.default_content()
 
-    @relaunch
     def execute_js(self, script, *args):
         logger.info(f'执行js脚本: \n{script}')
         self.d.execute_script(script, *args)
 
-    @relaunch
     def click(self, element):
         logger.info(f'点击元素: {element}')
         self.d.execute_script('arguments[0].click();', element)
 
-    @relaunch
     def quit(self):
         logger.info('退出浏览器')
         self.d.quit()
 
-    @relaunch
     def close(self):
         logger.info('关闭当前页签')
         self.d.close()
 
-    @relaunch
     def add_cookies(self, cookies: list):
         for cookie in cookies:
             self.d.add_cookie(cookie)
@@ -320,17 +313,14 @@ class BrowserDriver(object):
         logger.info(cookie)
         return cookie
 
-    @relaunch
     def delete_all_cookies(self):
         logger.info('删除所有cookie')
         self.d.delete_all_cookies()
 
-    @relaunch
     def delete_cookie(self, name):
         logger.info(f'删除cookie: {name}')
         self.d.delete_cookie(name)
 
-    @relaunch
     def refresh(self):
         logger.info(f'刷新当前页')
         self.d.refresh()
@@ -353,12 +343,10 @@ class BrowserDriver(object):
         logger.info(alert_text)
         return alert_text
 
-    @relaunch
     def accept_alert(self):
         logger.info('同意确认框')
         self.d.switch_to.alert.accept()
 
-    @relaunch
     def dismiss_alert(self):
         logger.info('取消确认框')
         self.d.switch_to.alert.dismiss()
