@@ -2,7 +2,6 @@ import inspect
 import os
 import time
 import platform
-
 import allure
 from selenium.webdriver.common.by import By
 from selenium.webdriver.common.keys import Keys
@@ -12,7 +11,6 @@ from selenium.webdriver.support.select import Select
 from selenium.webdriver.support.wait import WebDriverWait
 from selenium.webdriver.remote.webelement import WebElement as WE
 from qrunner.utils.log import logger
-from qrunner.core.browser.driver import relaunch
 from qrunner.utils.exceptions import ElementTypeError, NoSuchElementException
 from qrunner.core.browser.driver import BrowserDriver
 
@@ -53,7 +51,6 @@ class WebElement:
         self.driver: BrowserDriver = driver
         self.d = self.driver.d
 
-    @relaunch
     def _wait(self, timeout=3):
         try:
             WebDriverWait(self.d, timeout=timeout)\
@@ -62,7 +59,6 @@ class WebElement:
         except Exception:
             return False
 
-    @relaunch
     def _find_element(self, retry=3, timeout=5):
         while not self._wait(timeout=timeout):
             if retry > 0:
@@ -77,7 +73,6 @@ class WebElement:
         elements = self.d.find_elements(LOC_LIST[self.k], self.v)
         return elements
 
-    @relaunch
     def show_element(self, elem):
         """
                 Show the elements of the operation
@@ -101,7 +96,9 @@ class WebElement:
             self.driver.screenshot(f'{self._kwargs}-定位失败')
             raise NoSuchElementException(f'{self._kwargs}-定位失败')
         else:
-            self.driver.screenshot(f'{self._kwargs}')
+            element: WE = elements[self._index]
+            self.show_element(element)
+            self.driver.screenshot(f'{self._kwargs}-定位成功')
         return elements
 
     def get_element(self, retry=3, timeout=3):
@@ -112,6 +109,7 @@ class WebElement:
         else:
             element: WE = elements[self._index]
             self.show_element(element)
+            self.driver.screenshot(f'{self._kwargs}-定位成功')
         return element
 
     def exists(self, timeout=1):
@@ -122,64 +120,64 @@ class WebElement:
             return False
         return True
 
-    @relaunch
     def click(self):
         logger.info(f'点击元素: {self._kwargs}')
         self.get_element().click()
 
-    @relaunch
+    def click_exists(self):
+        logger.info(f'存在才点击元素: {self._kwargs},{self._index}')
+        if self.exists():
+            self.get_element().click()
+
     def slow_click(self):
         logger.info(f'移动到元素{self._kwargs}，然后点击')
         elem = self.get_element()
         ActionChains(self.d).move_to_element(elem).click(elem).perform()
 
-    @relaunch
     def right_click(self):
         logger.info(f'右键元素{self._kwargs}')
         elem = self.get_element()
         ActionChains(self.d).context_click(elem).perform()
 
-    @relaunch
     def move_to_elem(self):
         logger.info(f'鼠标移动到元素{self._kwargs}上')
         elem = self.get_element()
         ActionChains(self.d).move_to_element(elem).perform()
 
-    @relaunch
     def click_and_hold(self):
         logger.info(f'长按元素: {self._kwargs}')
         elem = self.get_element()
         ActionChains(self.d).click_and_hold(elem).perform()
 
-    @relaunch
     def drag_and_drop(self, x, y):
         logger.info(f'拖动元素{self._kwargs}到坐标{x},{y}')
         elem = self.get_element()
         action = ActionChains(self.d)
         action.drag_and_drop_by_offset(elem, x, y).perform()
 
-    @relaunch
     def double_click(self):
         logger.info(f'双击元素: {self._kwargs}')
         elem = self.get_element()
         ActionChains(self.d).double_click(elem).perform()
 
-    @relaunch
-    def send_keys(self, text):
+    def set_text(self, text):
         logger.info(f'点击元素: {self._kwargs}，然后输入: {text}')
         self.get_element().send_keys(text)
 
-    @relaunch
+    def set_and_enter(self, text):
+        logger.info(f'往 {self._kwargs} 输入 {text} 并回车')
+        element = self.get_element()
+        element.send_keys(text)
+        element.send_keys(Keys.ENTER)
+
     def clear_text(self):
         logger.info(f'清空文本')
         self.get_element().clear()
 
-    @relaunch
     def enter(self):
         logger.info(f'选中元素{self._kwargs}点击enter')
         self.get_element().send_keys(Keys.ENTER)
 
-    @relaunch
     def select_all(self) -> None:
         logger.info(f"选中元素{self._kwargs}, ctrl+a.")
         if platform.system().lower() == "darwin":
@@ -187,7 +185,6 @@ class WebElement:
         else:
             self.get_element().send_keys(Keys.CONTROL, "a")
 
-    @relaunch
     def cut(self) -> None:
         logger.info(f"选中元素{self._kwargs}, ctrl+x.")
         if platform.system().lower() == "darwin":
@@ -195,7 +192,6 @@ class WebElement:
         else:
             self.get_element().send_keys(Keys.CONTROL, "x")
 
-    @relaunch
     def copy(self) -> None:
         logger.info(f"选中元素{self._kwargs}, ctrl+c.")
         if platform.system().lower() == "darwin":
@@ -203,7 +199,6 @@ class WebElement:
         else:
             self.get_element().send_keys(Keys.CONTROL, "c")
 
-    @relaunch
     def paste(self) -> None:
         logger.info(f"选中元素{self._kwargs}, ctrl+v.")
         if platform.system().lower() == "darwin":
@@ -211,22 +206,18 @@ class WebElement:
         else:
             self.get_element().send_keys(Keys.CONTROL, "v")
 
-    @relaunch
     def backspace(self) -> None:
         logger.info(f"选中元素{self._kwargs}, backspace.")
         self.get_element().send_keys(Keys.BACKSPACE)
 
-    @relaunch
     def delete(self) -> None:
         logger.info(f"选中元素{self._kwargs}, delete.")
         self.get_element().send_keys(Keys.DELETE)
 
-    @relaunch
     def tab(self) -> None:
         logger.info(f"选中元素{self._kwargs}, tab.")
         self.get_element().send_keys(Keys.TAB)
 
-    @relaunch
     def space(self) -> None:
         logger.info(f"选中元素{self._kwargs}, space.")
         self.get_element().send_keys(Keys.SPACE)
@@ -243,7 +234,8 @@ class WebElement:
         logger.info(displayed)
         return displayed
 
-    def get_text(self):
+    @property
+    def text(self):
         logger.info(f'获取元素 {self._kwargs} 文本')
         element = self.get_element()
         text = element.text
@@ -257,40 +249,35 @@ class WebElement:
         logger.info(texts)
         return texts
 
-    @relaunch
     def select_index(self, index):
         logger.info(f'选择第 {index} 个下拉列表')
         element = self.get_element()
         select = Select(element)
         select.select_by_index(index)
 
-    @relaunch
     def select_value(self, value):
         logger.info(f'选择id为 {value} 的下拉列表')
         element = self.get_element()
         select = Select(element)
         select.select_by_value(value)
 
-    @relaunch
     def select_text(self, text):
         logger.info(f'选择下拉列表 {text} 选项')
         element = self.get_element()
         select = Select(element)
         select.select_by_value(text)
 
-    @relaunch
     def submit(self):
         logger.info(f'提交表单: {self._kwargs}')
         elem = self.get_element()
         elem.submit()
 
-    @relaunch
     def screenshot(self, file_name):
         """
-                截图并保存到预定路径并上传到allure报告
-                @param file_name: foo.png or fool
-                @return:
-                """
+        截图并保存到预定路径并上传到allure报告
+        @param file_name: foo.png or fool
+        @return:
+        """
         # 把文件名处理成test.png的样式
         if '.' in file_name:
             file_name = file_name.split(r'.')[0]
