@@ -3,32 +3,25 @@ from typing import Union
 from wda import Selector
 from qrunner.utils.log import logger
 from qrunner.utils.config import conf
-from qrunner.core.ios.driver import relaunch_wda, IosDriver
+from qrunner.core.ios.driver import IosDriver
 from multiprocessing.dummy import Pool as ThreadPool
 from selenium.common.exceptions import NoSuchElementException
 
 
-class IosConfig:
-    alerts = ['使用App时允许', '允许', '始终允许']
-
-
 class IosElement(object):
     """
     IOS原生元素定义
     """
-    def __init__(self, *args, **kwargs):
+    def __init__(self, driver=None, *args, **kwargs):
         # 从kwargs中删掉并返回index
         self._index = kwargs.pop('index', 0)
         # 参数初始化
-        self._pkg_name = conf.get_name('app', 'pkg_name')
-        self._resourceId = kwargs.pop('resourceId', '')
-        if self._resourceId:
-            kwargs['resourceId'] = f'{self._pkg_name}:{self._resourceId}'
         self._xpath = kwargs.get('xpath', '')
         self._kwargs = kwargs
-        self._element: Union[Selector] = None
-        self._serial_no = conf.get_name('app', 'serial_no')
-        self._driver = IosDriver.get_instance(self._serial_no)
+        self._element: Union[Selector]
+        self._driver: IosDriver = driver
+        self._serial_no = self._driver.serial_no
+        self._pkg_name = self._driver.bundle_id
         self._d = self._driver.d
 
     # 多线程处理异常弹窗
@@ -38,26 +31,23 @@ class IosElement(object):
         @return:
         """
         def click_alert(loc):
-            timeout = 2
-            try:
-                if '//' in loc:
-                    self._d.xpath(loc).click(timeout=timeout)
-                else:
-                    self._d(name=loc).click(timeout=timeout)
-            except Exception:
-                pass
-
-        # # 弹窗列表设置
-        # alert_list = []
-        # alert_list.extend(IosConfig.alerts)  # 添加上面定义的默认支持弹窗列表
-        # user_set_list = conf.get_name('app', 'alerts').split(',')
-        # alert_list.extend(user_set_list)  # 添加用例在running/conf.ini中设置的弹窗列表
+            if '//' in loc:
+                element = self._d.xpath(loc)
+            else:
+                element = self._d(label=loc)
+            element.click_exists(timeout=1)
 
         # 多线程执行点击过程
-        pool = ThreadPool(10)
-        pool.map(click_alert, IosConfig.alerts)
+        alert_str = conf.get_name('app', 'ios_alert')
+        logger.debug(f'处理异常弹窗: {alert_str}')
+        try:
+            alert_list = alert_str.split(',')
+        except:
+            alert_list = []
+        if alert_list:
+            pool = ThreadPool(10)
+            pool.map(click_alert, alert_list)
 
-    @relaunch_wda
     def _find_element(self, retry=3, timeout=3):
         """
         循环查找元素，查找失败先处理弹窗后重试
@@ -67,6 +57,7 @@ class IosElement(object):
         """
         self._element = self._d.xpath(self._xpath) if \
             self._xpath else self._d(**self._kwargs)[self._index]
+        self.handle_alert()
         while not self._element.wait(timeout=timeout):
             if retry > 0:
                 retry -= 1
@@ -88,10 +79,10 @@ class IosElement(object):
         """
         element: Union[Selector] = self._find_element(retry=retry, timeout=timeout)
         if element is None:
-            self._driver.screenshot(f'元素: {self._kwargs} 定位失败')
+            self._driver.screenshot(f'元素: {self._kwargs}-定位失败')
             raise NoSuchElementException(f'元素: {self._kwargs} 定位失败')
         else:
-            self._driver.screenshot(f'{self._kwargs}')
+            self._driver.screenshot(f'元素: {self._kwargs}-定位成功')
         return element
 
     @property
@@ -163,27 +154,22 @@ class IosElement(object):
         logger.info(flag)
         return flag
 
-    @relaunch_wda
     def click(self):
         logger.info(f'点击元素: {self._kwargs},{self._index}')
         self.get_element().click()
 
-    @relaunch_wda
     def click_exists(self):
         if self.exists():
             self.click()
 
-    @relaunch_wda
     def clear_text(self):
         logger.info('清除文本: {text}')
         self.get_element().clear_text()
 
-    @relaunch_wda
     def set_text(self, text):
         logger.info(f'输入框 {self._kwargs},{self._index} 输入: {text}')
         self.get_element().set_text(text)
 
-    @relaunch_wda
     def scroll(self, direction=None):
         """
         scroll to make element visiable
@@ -195,19 +181,15 @@ class IosElement(object):
         else:
             self.get_element().scroll()
 
-    @relaunch_wda
     def swipe_left(self):
         self.get_element().swipe("left")
 
-    @relaunch_wda
     def swipe_right(self):
         self.get_element().swipe("right")
 
-    @relaunch_wda
     def swipe_up(self):
         self.get_element().swipe("up")
 
-    @relaunch_wda
     def swipe_down(self):
         self.get_element().swipe("down")
 
