@@ -21,6 +21,7 @@ class TestMain(object):
                  concurrent=False,
                  base_url=None,
                  headers=None,
+                 login_key=None,
                  timeout=30,
                  report_path='report'
                  ):
@@ -37,6 +38,7 @@ class TestMain(object):
             "accessToken": "xxxx",
             "signature": "xxxx"
         }
+        :@param login_key：headers中跟登录相关的key
         :@param timeout: 接口请求超时时间
         :@param report_path: 报告生成目录
         """
@@ -50,6 +52,7 @@ class TestMain(object):
         self.concurrent = concurrent
         self.base_url = base_url
         self.headers = headers
+        self.login_key = login_key
         self.timeout = str(timeout)
         self.report_path = report_path
 
@@ -69,7 +72,9 @@ class TestMain(object):
                 print('base_url未配置，请配置后重新执行~')
                 sys.exit()
         if self.headers is not None:
-            conf.set_name('api', 'headers', json.dumps(self.headers))
+            conf.set_name('common', 'headers', json.dumps(self.headers))
+        if login_key is not None:
+            conf.set_name('api', 'login_key', json.dumps(self.login_key))
         if self.timeout is not None:
             conf.set_name('common', 'timeout', self.timeout)
         conf.set('common', 'report_path', self.report_path)
@@ -96,7 +101,7 @@ class TestMain(object):
         pytest.main(cmd_list)
 
         # 用例完成后操作
-        conf.set_name('api', 'headers', json.dumps({}))  # 清除登录态
+        conf.set_name('common', 'headers', json.dumps({}))  # 清除登录态
         os.system(f'allure generate allure-results -o {self.report_path} --clean')  # 生成报告
 
 
