@@ -82,7 +82,7 @@ require_content = """qrunner
 """
 
 ignore_content = "\n".join(
-    ["__pycache__/*", "*.pyc", ".idea/*", ".DS_Store", "allure-results"]
+    ["__pycache__/*", "*.pyc", ".idea/*", ".DS_Store", "allure-results", "report"]
 )
 
 data_content = """
