@@ -3,35 +3,64 @@
 """
 import json
 import os
-
 import allure
 import pytest
 import inspect as sys_inspect
 
 
+# 报告模块
 def feature(text):
     return allure.feature(text)
 
 
+# 报告子模块
 def story(text):
     return allure.story(text)
 
 
-# 兼容历史版本
+# 报告子模块，兼容历史版本
 def module(text):
     return allure.story(text)
 
 
+# 报告标题
 def title(text):
     return allure.title(text)
 
 
+def order(index):
+    """
+    指定用例执行顺序
+    doc: https://blog.csdn.net/weixin_43880991/article/details/116221362
+    """
+    return pytest.mark.run(order=index)
+
+
+def depend(*args, **kwargs):
+    """
+    设置用例依赖关系
+    doc: https://www.cnblogs.com/se7enjean/p/13513131.html
+    """
+    return pytest.mark.depenency(*args, **kwargs)
+
+
+# 参数化数据
 def data(*args, **kwargs):
+    """
+    @data('key1,key2', [[value1, value2], [value3, value4]])
+    """
     return pytest.mark.parametrize(*args, **kwargs)
 
 
-# 有空把文件装饰器补上
+# 从json文件获取数据进行参数化
 def file_data(data_key=None, file_name=None):
+    """
+    @file_data('key1,key2', 'data.json')
+    data.json
+        {
+            "key1,key2": [[value1, value2], [value3, value4]]
+        }
+    """
     # 获取被装饰方法的目录
     stack_t = sys_inspect.stack()
     ins = sys_inspect.getframeinfo(stack_t[1][0])
