@@ -6,12 +6,10 @@ import urllib.parse
 import requests
 import json
 from qrunner.utils.allure_data import AllureData
-
-
-# 钉钉机器人
 from qrunner.utils.config import conf
 
 
+# 钉钉机器人
 class Robot:
     def __init__(self, secret=None, url=None):
         self.secret = secret
@@ -63,7 +61,8 @@ class Robot:
         else:
             color_str = color_green
 
-        result_text = "### *{0}*\n\n" \
+        msg_title = f'{msg_title}-{time.strftime("%Y%m%d%H")}'
+        result_text = "### {0}\n\n" \
                       "<font color=#C0C0C0>总数：</font>{1}，" \
                       "<font color=#C0C0C0>通过：</font><font color=#C0C0C0>{2}，</font>\n" \
                       "<font color=#C0C0C0>失败：</font><font color=#C0C0C0>{3}，</font>\n" \
